antares.apps.document.exceptions package — Antares 0.0.2 documentation

# antares.apps.document.exceptions package

## Submodules

## antares.apps.document.exceptions.document_does_not_exist_exception module

exception `antares.apps.document.exceptions.document_does_not_exist_exception.` `DocumentDoesNotExistException`(value)

  Bases: `Exception`

## antares.apps.document.exceptions.document_field_not_found module

Created on Jun 19, 2016

@author: leobelen

exception `antares.apps.document.exceptions.document_field_not_found.` `DocumentFieldNotFound`(value)

  Bases: `Exception`

## antares.apps.document.exceptions.document_required_exception module

exception `antares.apps.document.exceptions.document_required_exception.` `DocumentRequiredException`(value)

  Bases: `Exception`

## antares.apps.document.exceptions.document_status_exception module

exception `antares.apps.document.exceptions.document_status_exception.` `DocumentStatusException`(value)

  Bases: `Exception`

## antares.apps.document.exceptions.document_validation_exception module

exception `antares.apps.document.exceptions.document_validation_exception.` `DocumentValidationException`(value)

  Bases: `Exception`

## antares.apps.document.exceptions.form_definition_not_found_exception module

exception `antares.apps.document.exceptions.form_definition_not_found_exception.` `FormDefinitionNotFoundException`(value)

  Bases: `Exception`

## antares.apps.document.exceptions.form_defintion_is_not_active_exception module

Created on Jun 15, 2016

@author: leobelen

exception `antares.apps.document.exceptions.form_defintion_is_not_active_exception.` `FormDefintionIsNotActiveException`(value)

  Bases: `Exception`

## antares.apps.document.exceptions.invalid_document_status_exception module

Created on Jun 17, 2016

@author: leobelen

exception `antares.apps.document.exceptions.invalid_document_status_exception.` `InvalidDocumentStatusException`(value)

  Bases: `Exception`

  classdocs

## antares.apps.document.exceptions.invalid_document_value_exception module

Created on Jun 26, 2016

@author: leobelen

exception `antares.apps.document.exceptions.invalid_document_value_exception.` `InvalidDocumentValueException`(value)

  Bases: `Exception`

  classdocs

## antares.apps.document.exceptions.invalid_form_definition_exception module

Created on Jun 14, 2016

@author: leobelen

exception `antares.apps.document.exceptions.invalid_form_definition_exception.` `InvalidFormDefinitionException`(value)

  Bases: `Exception`

## Module contents